#' Climate index
#'
#' This is a time series of climate index.
#'
#'
#' @examples
#' head(climate_indices)
"climate_indices"

#' Dow Jones stock price
#'
#' It includes 29 time series of stock series in Dow Jones.
#'
#'
#' @examples
#' head(DJS)
"DJS"

#' A data from Illapel
#'
#' Raw rodent and rainfall data from the study site at Las Chinchillas National Reserve near the city of Illapel, Coquimbo Region of Chil.
#'
#'
#' @examples
#' head(AUCO)
"AUCO"
